window.Gleam.initSearch([{"doc":"gleam_community_ansi","title":"gleam_community_ansi","content":"# gleam-community/ansi\n\nFormat text with ANSI escape sequences.\n\n[![Package Version](https://img.shields.io/hexpm/v/gleam_community_ansi)](https://hex.pm/packages/gleam_community_ansi)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleam_community_ansi/)\n\n✨ This project is written in _pure Gleam_ so you can use it anywhere Gleam runs:\nErlang, Elixir, Node, Deno, even [some browsers](https://bit.ly/devtools-console-ansi-support)!\n\n---\n\n## Quickstart\n\n```gleam\nimport gleam/io\nimport gleam_community/ansi\n\npub fn main() {\n  let greeting = &quot;Hello, &quot; &lt;&gt; ansi.pink(&quot;world&quot;) &lt;&gt; &quot;!&quot;\n\n  greeting\n  |&gt; ansi.bg_white\n  |&gt; io.println\n}\n\n```\n\n## Installation\n\n`gleam_community` packages are published to [hex.pm](https://hex.pm/packages/gleam_community_ansi)\nwith the prefix `gleam_community_`. You can add them to your Gleam projects directly:\n\n```sh\ngleam add gleam_community_ansi\n```\n\nThe docs can be found over at [hexdocs.pm](https://hexdocs.pm/gleam_community_ansi).\n\n## ANSI-what?\n\nANSI escape sequences date back to the 70s as a standard way to format text on\nvarious video text terminals. Since then they have been adopted by many software\nterminal emulators and platforms, including some Web browsers, and are a simple\nway to format text without platform-specific APIs.\n\nThe point of this package is to abstract the specific codes away and give you an\neasy-to-understand API for formatting and colouring terminal text. Still, here is\na quick couple of examples of what&#39;s happening under the hood.\n\nYou can copy these examples straight into your terminal to see them in action!\n\n- Colour text yellow:\n\n  ```shell\n  $ echo &quot;\\e[33mhello&quot;\n  ```\n\n- Colour the background pink:\n\n  ```shell\n  $ echo &quot;\\e[45mhello&quot;\n  ```\n\n- Render text italic:\n\n  ```shell\n  $ echo &quot;\\e[3mhello\\e[23m&quot;\n  ```\n\nAs you can see, the escape sequences are a bit obscure. Sure, you could hard code\nthem, or you could use this package!\n","url":"index.html"},{"doc":"gleam_community/ansi","title":"bg_black","content":"pub fn bg_black(text: String) -&gt; String\n Colour the given text&#39;s background black.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bg_black(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[40mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_black\ngleam_community/ansi bg_black","url":"gleam_community/ansi.html#bg_black"},{"doc":"gleam_community/ansi","title":"bg_blue","content":"pub fn bg_blue(text: String) -&gt; String\n Colour the given text&#39;s background blue.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bg_blue(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[44mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_blue\ngleam_community/ansi bg_blue","url":"gleam_community/ansi.html#bg_blue"},{"doc":"gleam_community/ansi","title":"bg_bright_black","content":"pub fn bg_bright_black(text: String) -&gt; String\n Colour the given text&#39;s background bright black.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bg_bright_black(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[100mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_bright_black\ngleam_community/ansi bg_bright_black","url":"gleam_community/ansi.html#bg_bright_black"},{"doc":"gleam_community/ansi","title":"bg_bright_blue","content":"pub fn bg_bright_blue(text: String) -&gt; String\n Colour the given text&#39;s background bright blue.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bg_bright_blue(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[104mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_bright_blue\ngleam_community/ansi bg_bright_blue","url":"gleam_community/ansi.html#bg_bright_blue"},{"doc":"gleam_community/ansi","title":"bg_bright_cyan","content":"pub fn bg_bright_cyan(text: String) -&gt; String\n Colour the given text&#39;s background bright cyan.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bg_bright_cyan(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[106mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_bright_cyan\ngleam_community/ansi bg_bright_cyan","url":"gleam_community/ansi.html#bg_bright_cyan"},{"doc":"gleam_community/ansi","title":"bg_bright_green","content":"pub fn bg_bright_green(text: String) -&gt; String\n Colour the given text&#39;s background bright green.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bg_bright_green(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[102mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_bright_green\ngleam_community/ansi bg_bright_green","url":"gleam_community/ansi.html#bg_bright_green"},{"doc":"gleam_community/ansi","title":"bg_bright_magenta","content":"pub fn bg_bright_magenta(text: String) -&gt; String\n Colour the given text&#39;s background bright magenta.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bg_bright_magenta(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[105mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_bright_magenta\ngleam_community/ansi bg_bright_magenta","url":"gleam_community/ansi.html#bg_bright_magenta"},{"doc":"gleam_community/ansi","title":"bg_bright_red","content":"pub fn bg_bright_red(text: String) -&gt; String\n Colour the given text&#39;s background bright red.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bg_bright_red(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[101mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_bright_red\ngleam_community/ansi bg_bright_red","url":"gleam_community/ansi.html#bg_bright_red"},{"doc":"gleam_community/ansi","title":"bg_bright_white","content":"pub fn bg_bright_white(text: String) -&gt; String\n Colour the given text&#39;s background bright white.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bg_bright_white(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[107mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_bright_white\ngleam_community/ansi bg_bright_white","url":"gleam_community/ansi.html#bg_bright_white"},{"doc":"gleam_community/ansi","title":"bg_bright_yellow","content":"pub fn bg_bright_yellow(text: String) -&gt; String\n Colour the given text&#39;s background bright yellow.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bg_bright_yellow(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[103mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_bright_yellow\ngleam_community/ansi bg_bright_yellow","url":"gleam_community/ansi.html#bg_bright_yellow"},{"doc":"gleam_community/ansi","title":"bg_color","content":"pub fn bg_color(text: String, colour: Colour) -&gt; String\n This is an alias for [`bg_colour`](#bg_colour) for those who prefer the American English\n spelling.\n\nSynonyms:\ngleam_community/ansi.bg_color\ngleam_community/ansi bg_color","url":"gleam_community/ansi.html#bg_color"},{"doc":"gleam_community/ansi","title":"bg_colour","content":"pub fn bg_colour(text: String, colour: Colour) -&gt; String\n Colour the given text&#39;s background with the given colour represented by a `Colour`.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n import gleam_community/colour.{Colour}\n\n fn example() {\n   let pink = colour.from_hsl(0.8583, 1.0, 0,84)\n   ansi.bg_colour(&quot;lucy&quot;, pink)\n   // =&gt; &quot;\\x1B[48;2;255;175;243mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_colour\ngleam_community/ansi bg_colour","url":"gleam_community/ansi.html#bg_colour"},{"doc":"gleam_community/ansi","title":"bg_cyan","content":"pub fn bg_cyan(text: String) -&gt; String\n Colour the given text&#39;s background cyan.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bg_cyan(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[46mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_cyan\ngleam_community/ansi bg_cyan","url":"gleam_community/ansi.html#bg_cyan"},{"doc":"gleam_community/ansi","title":"bg_green","content":"pub fn bg_green(text: String) -&gt; String\n Colour the given text&#39;s background green.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bg_green(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[42mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_green\ngleam_community/ansi bg_green","url":"gleam_community/ansi.html#bg_green"},{"doc":"gleam_community/ansi","title":"bg_hex","content":"pub fn bg_hex(text: String, colour: Int) -&gt; String\n Colour the given text&#39;s background the given colour represented by a hex `Int`.\n\n The given hex Int can be any valid [shorthand hexadecimal form](https://en.wikipedia.org/wiki/Web_colors#Shorthand_hexadecimal_form).\n\n ❗️ Note that if supplied hex Int is less than 0 or larger than 0xfffff the\n colour will be set to black and white respectively.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.hex(&quot;lucy&quot;, 0xffaff3)\n   // =&gt; &quot;\\x1B[48;2;255;175;243mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_hex\ngleam_community/ansi bg_hex","url":"gleam_community/ansi.html#bg_hex"},{"doc":"gleam_community/ansi","title":"bg_magenta","content":"pub fn bg_magenta(text: String) -&gt; String\n Colour the given text&#39;s background magenta.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bg_magenta(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[45mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_magenta\ngleam_community/ansi bg_magenta","url":"gleam_community/ansi.html#bg_magenta"},{"doc":"gleam_community/ansi","title":"bg_pink","content":"pub fn bg_pink(text: String) -&gt; String\n Colour the given text&#39;s background pink.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bg_pink(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[48;2;255;175;243mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_pink\ngleam_community/ansi bg_pink","url":"gleam_community/ansi.html#bg_pink"},{"doc":"gleam_community/ansi","title":"bg_red","content":"pub fn bg_red(text: String) -&gt; String\n Colour the given text&#39;s background red.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bg_red(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[41mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_red\ngleam_community/ansi bg_red","url":"gleam_community/ansi.html#bg_red"},{"doc":"gleam_community/ansi","title":"bg_white","content":"pub fn bg_white(text: String) -&gt; String\n Colour the given text&#39;s background white.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bg_white(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[47mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_white\ngleam_community/ansi bg_white","url":"gleam_community/ansi.html#bg_white"},{"doc":"gleam_community/ansi","title":"bg_yellow","content":"pub fn bg_yellow(text: String) -&gt; String\n Colour the given text&#39;s background yellow.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bg_yellow(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[43mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bg_yellow\ngleam_community/ansi bg_yellow","url":"gleam_community/ansi.html#bg_yellow"},{"doc":"gleam_community/ansi","title":"black","content":"pub fn black(text: String) -&gt; String\n Colour the given text black.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.black(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[30mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.black\ngleam_community/ansi black","url":"gleam_community/ansi.html#black"},{"doc":"gleam_community/ansi","title":"blue","content":"pub fn blue(text: String) -&gt; String\n Colour the given text blue.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.blue(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[34mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.blue\ngleam_community/ansi blue","url":"gleam_community/ansi.html#blue"},{"doc":"gleam_community/ansi","title":"bold","content":"pub fn bold(text: String) -&gt; String\n Style the given text bold.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bold(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[1mlucy\\x1B[22m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[22m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; bold/dim style of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n style, it will use both the outter style and the inner style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.dim(&quot;Isn&#39;t &quot; &lt;&gt; ansi.bold(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be dim but the text &quot;fun?&quot; will be\n both underlined, *and* bold!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bold\ngleam_community/ansi bold","url":"gleam_community/ansi.html#bold"},{"doc":"gleam_community/ansi","title":"bright_black","content":"pub fn bright_black(text: String) -&gt; String\n Colour the given text bright black. This should increase the luminosity of\n the base colour, but some terminals will interpret this as bold instead.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bright_black(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[90mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bright_black\ngleam_community/ansi bright_black","url":"gleam_community/ansi.html#bright_black"},{"doc":"gleam_community/ansi","title":"bright_blue","content":"pub fn bright_blue(text: String) -&gt; String\n Colour the given text bright blue. This should increase the luminosity of\n the base colour, but some terminals will interpret this as bold instead.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n fn example() {\n   ansi.bright_blue(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[94mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bright_blue\ngleam_community/ansi bright_blue","url":"gleam_community/ansi.html#bright_blue"},{"doc":"gleam_community/ansi","title":"bright_cyan","content":"pub fn bright_cyan(text: String) -&gt; String\n Colour the given text bright cyan. This should increase the luminosity of\n the base colour, but some terminals will interpret this as bold instead.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n fn example() {\n   ansi.bright_cyan(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[96mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bright_cyan\ngleam_community/ansi bright_cyan","url":"gleam_community/ansi.html#bright_cyan"},{"doc":"gleam_community/ansi","title":"bright_green","content":"pub fn bright_green(text: String) -&gt; String\n Colour the given text bright green. This should increase the luminosity of\n the base colour, but some terminals will interpret this as bold instead.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n fn example() {\n   ansi.bright_green(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[92mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bright_green\ngleam_community/ansi bright_green","url":"gleam_community/ansi.html#bright_green"},{"doc":"gleam_community/ansi","title":"bright_magenta","content":"pub fn bright_magenta(text: String) -&gt; String\n Colour the given text bright gremagentaen. This should increase the luminosity\n of the base colour, but some terminals will interpret this as bold instead.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n fn example() {\n   ansi.bright_magenta(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[95mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bright_magenta\ngleam_community/ansi bright_magenta","url":"gleam_community/ansi.html#bright_magenta"},{"doc":"gleam_community/ansi","title":"bright_red","content":"pub fn bright_red(text: String) -&gt; String\n Colour the given text bright red. This should increase the luminosity of\n the base colour, but some terminals will interpret this as bold instead.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.bright_red(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[91mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bright_red\ngleam_community/ansi bright_red","url":"gleam_community/ansi.html#bright_red"},{"doc":"gleam_community/ansi","title":"bright_white","content":"pub fn bright_white(text: String) -&gt; String\n Colour the given text bright white. This should increase the luminosity of\n the base colour, but some terminals will interpret this as bold instead.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n fn example() {\n   ansi.bright_white(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[97mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bright_white\ngleam_community/ansi bright_white","url":"gleam_community/ansi.html#bright_white"},{"doc":"gleam_community/ansi","title":"bright_yellow","content":"pub fn bright_yellow(text: String) -&gt; String\n Colour the given text bright yellow. This should increase the luminosity of\n the base colour, but some terminals will interpret this as bold instead.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n fn example() {\n   ansi.bright_yellow(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[93mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.bright_yellow\ngleam_community/ansi bright_yellow","url":"gleam_community/ansi.html#bright_yellow"},{"doc":"gleam_community/ansi","title":"color","content":"pub fn color(text: String, color: Colour) -&gt; String\n This is an alias for [`colour`](#colour) for those who prefer the American English\n spelling.\n\nSynonyms:\ngleam_community/ansi.color\ngleam_community/ansi color","url":"gleam_community/ansi.html#color"},{"doc":"gleam_community/ansi","title":"colour","content":"pub fn colour(text: String, colour: Colour) -&gt; String\n Colour the given text the given colour represented by a `Colour`.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n import gleam_community/colour.{Colour}\n\n fn example() {\n   let pink = colour.from_hsl(0.8583, 1.0, 0,84)\n   ansi.colour(&quot;lucy&quot;, pink)\n   // =&gt; &quot;\\x1B[48;2;255;175;243mlucy\\x1B[49m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.colour\ngleam_community/ansi colour","url":"gleam_community/ansi.html#colour"},{"doc":"gleam_community/ansi","title":"cyan","content":"pub fn cyan(text: String) -&gt; String\n Colour the given text cyan.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.cyan(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[36mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.cyan\ngleam_community/ansi cyan","url":"gleam_community/ansi.html#cyan"},{"doc":"gleam_community/ansi","title":"dim","content":"pub fn dim(text: String) -&gt; String\n Style the given text&#39;s colour to be dimmer.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.dim(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[2mlucy\\x1B[22m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[22m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; bold/dim style of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n style, it will use both the outter style and the inner style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.dim(&quot;Isn&#39;t &quot; &lt;&gt; ansi.bold(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be dim but the text &quot;fun?&quot; will be\n both underlined, *and* bold!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.dim\ngleam_community/ansi dim","url":"gleam_community/ansi.html#dim"},{"doc":"gleam_community/ansi","title":"gray","content":"pub fn gray(text: String) -&gt; String\n This is an alias for [`grey`](#grey) for those who prefer the American English\n spelling.\n\nSynonyms:\ngleam_community/ansi.gray\ngleam_community/ansi gray","url":"gleam_community/ansi.html#gray"},{"doc":"gleam_community/ansi","title":"green","content":"pub fn green(text: String) -&gt; String\n Colour the given text green.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.green(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[32mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.green\ngleam_community/ansi green","url":"gleam_community/ansi.html#green"},{"doc":"gleam_community/ansi","title":"grey","content":"pub fn grey(text: String) -&gt; String\n Colour the given text gray.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.gray(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[90mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.grey\ngleam_community/ansi grey","url":"gleam_community/ansi.html#grey"},{"doc":"gleam_community/ansi","title":"hex","content":"pub fn hex(text: String, colour: Int) -&gt; String\n Colour the given text the given colour represented by a hex `Int`.\n\n The given hex Int can be any valid [shorthand hexadecimal form](https://en.wikipedia.org/wiki/Web_colors#Shorthand_hexadecimal_form).\n\n ❗️ Note that if supplied hex Int is less than 0 or larger than 0xfffff the\n colour will be set to black and white respectively.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.hex(&quot;lucy&quot;, 0xffaff3)\n   // =&gt; &quot;\\x1B[38;2;255;175;243mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[49m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.hex\ngleam_community/ansi hex","url":"gleam_community/ansi.html#hex"},{"doc":"gleam_community/ansi","title":"hidden","content":"pub fn hidden(text: String) -&gt; String\n Style the given text to be hidden.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.hidden(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[8mlucy\\x1B[28m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[28m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; hidden style of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n style, it will use both the outter style and the inner style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.dim(&quot;Isn&#39;t &quot; &lt;&gt; ansi.bold(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be dim but the text &quot;fun?&quot; will be\n both underlined, *and* bold!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.hidden\ngleam_community/ansi hidden","url":"gleam_community/ansi.html#hidden"},{"doc":"gleam_community/ansi","title":"inverse","content":"pub fn inverse(text: String) -&gt; String\n Inverse the given text&#39;s colour, and background colour.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.inverse(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[7mlucy\\x1B[27m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[27m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; inverse style of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n style, it will use both the outter style and the inner style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.dim(&quot;Isn&#39;t &quot; &lt;&gt; ansi.bold(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be dim but the text &quot;fun?&quot; will be\n both underlined, *and* bold!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.inverse\ngleam_community/ansi inverse","url":"gleam_community/ansi.html#inverse"},{"doc":"gleam_community/ansi","title":"italic","content":"pub fn italic(text: String) -&gt; String\n Style the given text italic.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.italic(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[3mlucy\\x1B[23m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[23m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; italic style of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n style, it will use both the outter style and the inner style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.underline(&quot;Isn&#39;t &quot; &lt;&gt; ansi.bold(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be underlined but the text &quot;fun?&quot; will be\n both underlined, *and* bold!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.italic\ngleam_community/ansi italic","url":"gleam_community/ansi.html#italic"},{"doc":"gleam_community/ansi","title":"magenta","content":"pub fn magenta(text: String) -&gt; String\n Colour the given text magenta.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.magenta(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[35mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.magenta\ngleam_community/ansi magenta","url":"gleam_community/ansi.html#magenta"},{"doc":"gleam_community/ansi","title":"pink","content":"pub fn pink(text: String) -&gt; String\n Colour the given text pink.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.pink(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[38;2;255;175;243mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.pink\ngleam_community/ansi pink","url":"gleam_community/ansi.html#pink"},{"doc":"gleam_community/ansi","title":"red","content":"pub fn red(text: String) -&gt; String\n Colour the given text red.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.red(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[31mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.red\ngleam_community/ansi red","url":"gleam_community/ansi.html#red"},{"doc":"gleam_community/ansi","title":"reset","content":"pub fn reset(text: String) -&gt; String\n Reset the text modified\nSynonyms:\ngleam_community/ansi.reset\ngleam_community/ansi reset","url":"gleam_community/ansi.html#reset"},{"doc":"gleam_community/ansi","title":"strikethrough","content":"pub fn strikethrough(text: String) -&gt; String\n Style the given text to be striked through.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.strikethrough(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[9mlucy\\x1B[29m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[29m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; strikethrough style of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n style, it will use both the outter style and the inner style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.dim(&quot;Isn&#39;t &quot; &lt;&gt; ansi.bold(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be dim but the text &quot;fun?&quot; will be\n both underlined, *and* bold!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.strikethrough\ngleam_community/ansi strikethrough","url":"gleam_community/ansi.html#strikethrough"},{"doc":"gleam_community/ansi","title":"strip","content":"pub fn strip(text: String) -&gt; String\n Strips the ansi control characters from the text.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   let bold_lucy = ansi.bold(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[1mlucy\\x1B[22m&quot;\n   ansi.strip(bold_lucy)\n   // =&gt; &quot;lucy&quot;\n }\n \n\n In this example, the text &quot;lucy&quot; is boldened by `ansi.bold` and then converted back to the original\n string with `ansi.strip`.\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.strip\ngleam_community/ansi strip","url":"gleam_community/ansi.html#strip"},{"doc":"gleam_community/ansi","title":"underline","content":"pub fn underline(text: String) -&gt; String\n Style the given text&#39;s colour to be dimmer.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.underline(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[4mlucy\\x1B[24m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[24m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; underline style of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n style, it will use both the outter style and the inner style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.dim(&quot;Isn&#39;t &quot; &lt;&gt; ansi.bold(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be dim but the text &quot;fun?&quot; will be\n both underlined, *and* bold!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.underline\ngleam_community/ansi underline","url":"gleam_community/ansi.html#underline"},{"doc":"gleam_community/ansi","title":"white","content":"pub fn white(text: String) -&gt; String\n Colour the given text white.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.white(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[37mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.white\ngleam_community/ansi white","url":"gleam_community/ansi.html#white"},{"doc":"gleam_community/ansi","title":"yellow","content":"pub fn yellow(text: String) -&gt; String\n Colour the given text yellow.\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;lucy&quot;)\n   // =&gt; &quot;\\x1B[33mlucy\\x1B[39m&quot;\n }\n \n\n ❗️ Note the trailing `&quot;\\x1B[39m&quot;` added to the string. This is the escape code\n for the &quot;default&quot; colour of the terminal. This means text you write after\n this will revert back to default.\n\n ✨ `gleam_community/ansi` is smart about nested styles; instead of using the default\n colour, it will use the colour of the outter style.\n\n \n import gleam_community/ansi\n\n fn example() {\n   ansi.yellow(&quot;Isn&#39;t &quot; &lt;&gt; ansi.pink(&quot;Gleam&quot;) &lt;&gt; &quot; fun?&quot;)\n }\n \n\n In this example, the text &quot;Gleam&quot; will be pink but the text &quot;fun?&quot; will be\n yellow, *not* the default colour!\n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/gleam-community/ansi/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/ansi.yellow\ngleam_community/ansi yellow","url":"gleam_community/ansi.html#yellow"},{"doc":"gleam_community/ansi","title":"gleam_community/ansi","content":"\n - **Text style**\n   - [`bold`](#bold)\n   - [`italic`](#italic)\n   - [`underline`](#underline)\n   - [`strikethrough`](#strikethrough)\n   - [`inverse`](#inverse)\n   - [`dim`](#dim)\n   - [`hidden`](#hidden)\n   - [`reset`](#reset)\n - **Text colour**\n   - [`black`](#black)\n   - [`red`](#red)\n   - [`green`](#green)\n   - [`yellow`](#yellow)\n   - [`blue`](#blue)\n   - [`magenta`](#magenta)\n   - [`cyan`](#cyan)\n   - [`white`](#white)\n   - [`pink`](#pink)\n   - [`grey`](#grey)\n   - [`gray`](#gray)\n   - [`bright_black`](#bright_black)\n   - [`bright_red`](#bright_red)\n   - [`bright_green`](#bright_green)\n   - [`bright_yellow`](#bright_yellow)\n   - [`bright_blue`](#bright_blue)\n   - [`bright_magenta`](#bright_magenta)\n   - [`bright_cyan`](#bright_cyan)\n   - [`bright_white`](#bright_white)\n   - [`hex`](#hex)\n   - [`colour`](#colour)\n   - [`color`](#color)\n - **Background colour**\n   - [`bg_black`](#bg_black)\n   - [`bg_red`](#bg_red)\n   - [`bg_green`](#bg_green)\n   - [`bg_yellow`](#bg_yellow)\n   - [`bg_blue`](#bg_blue)\n   - [`bg_magenta`](#bg_magenta)\n   - [`bg_cyan`](#bg_cyan)\n   - [`bg_white`](#bg_white)\n   - [`bg_pink`](#bg_pink)\n   - [`bg_bright_black`](#bg_bright_black)\n   - [`bg_bright_red`](#bg_bright_red)\n   - [`bg_bright_green`](#bg_bright_green)\n   - [`bg_bright_yellow`](#bg_bright_yellow)\n   - [`bg_bright_blue`](#bg_bright_blue)\n   - [`bg_bright_magenta`](#bg_bright_magenta)\n   - [`bg_bright_cyan`](#bg_bright_cyan)\n   - [`bg_bright_white`](#bg_bright_white)\n   - [`bg_hex`](#bg_hex)\n   - [`bg_colour`](#bg_colour)\n   - [`bg_color`](#bg_color)\n - **Utilities**\n   - [`strip`](#strip)\n\n ---\n\n This package was heavily inspired by the `colors` module in the Deno standard\n library. The original source code can be found\n &lt;a href=&quot;https://deno.land/std@0.167.0/fmt/colors.ts&quot;&gt;here&lt;/a&gt;.\n\n &lt;details&gt;\n &lt;summary&gt;The license of that package is produced below:&lt;/summary&gt;\n\n\n &gt; MIT License\n\n &gt; Copyright 2018-2022 the Deno authors.\n\n &gt; Permission is hereby granted, free of charge, to any person obtaining a copy\n of this software and associated documentation files (the &quot;Software&quot;), to deal\n in the Software without restriction, including without limitation the rights\n to use, copy, modify, merge, publish, distribute, sublicense, and/or sell\n copies of the Software, and to permit persons to whom the Software is\n furnished to do so, subject to the following conditions:\n\n &gt; The above copyright notice and this permission notice shall be included in all\n copies or substantial portions of the Software.\n &lt;/details&gt;\n","url":"gleam_community/ansi.html"}]);